@@ -1,11 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import copy
 from unittest import TestCase
-from pydiploy.require.python.utils import python_pkg, application_dependencies
-from pydiploy.require.python.virtualenv import virtualenv
+
 from fabric.api import env
-from mock import patch, call, Mock
+from mock import call, Mock, patch
+from pydiploy.require.python.utils import application_dependencies, python_pkg
+from pydiploy.require.python.virtualenv import virtualenv
 
 
 class UtilsCheck(TestCase):
@@ -15,6 +17,7 @@ class UtilsCheck(TestCase):
     """
 
     def setUp(self):
+        self.previous_env = copy.deepcopy(env)
         env.remote_virtualenv_dir = "remote_virtualenv_dir"
         env.remote_current_path = "remote_current_path"
         env.goal = "goal"
@@ -24,6 +27,7 @@ class UtilsCheck(TestCase):
 
     def tearDown(self):
         env.clear()
+        env.update(self.previous_env)
 
     @patch('fabtools.require.deb.packages', return_value=Mock())
     @patch('fabtools.require.python.install', return_value=Mock())
@@ -65,6 +69,14 @@ class UtilsCheck(TestCase):
         self.assertEqual(install_requirements.call_args, call(
             'requirements/goal.txt', pip_cmd='pip', use_sudo=True, upgrade=False, user='remote_owner'))
 
+        # test oracle
+
+        env.oracle_client_version = ''
+        env.oracle_remote_dir = ''
+        env.remote_home = ''
+
+        application_dependencies(False)
+
 
 class VirtualEnvCheck(TestCase):
 
@@ -73,6 +85,7 @@ class VirtualEnvCheck(TestCase):
     """
 
     def setUp(self):
+        self.previous_env = copy.deepcopy(env)
         env.remote_group = "remote_group"
         env.remote_python_version = "2.7"
         env.remote_virtualenv_dir = "remote_virtualenv_dir"
@@ -80,6 +93,7 @@ class VirtualEnvCheck(TestCase):
 
     def tearDown(self):
         env.clear()
+        env.update(self.previous_env)
 
     @patch('fabtools.require.files.directory', return_value=Mock())
     @patch('fabtools.require.python.virtualenv', return_value=Mock())
